# Imagenius


## Overview

Imagenius is a web-based application designed to automatically tag images based on their content. Built on advanced machine learning models, Imagenius provides fast, accurate, and comprehensive tagging solutions for your photo galleries.


## Features

- **Web-based GUI**: Intuitive drag-and-drop interface for easy image uploads.
- **Advanced Object Detection**: Utilizes state-of-the-art machine learning models for accurate tagging.
- **Modular Backend**: Python-based backend, easily extendable for future models and features.



## Quick Start

### Setup

Clone the repository and navigate into the folder. Then install the dependencies.

```bash
git clone https://github.com/0xchrisw/imagenius.git
pip install -e .
imagenius
```

### Usage

1. Open your web browser and go to `http://localhost:3000`.
2. Drag and drop an image onto the upload area or select an image via the file picker.
3. View the automatically generated tags for the image.


## To Do
  [ ] Move tags to database to enable more efficient tag modification and searching.


## Contributions

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
